pitchtools.ObjectSegment
========================

.. inheritance-diagram:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Methods
-------

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.count

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.index

    Inherited from :py:class:`__builtin__.tuple`

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__add__

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__contains__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__eq__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__ge__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__getitem__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__getslice__

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__gt__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__hash__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__iter__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__le__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__len__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__lt__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__mul__

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__ne__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__repr__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.pitchtools.ObjectSegment.ObjectSegment.ObjectSegment.__rmul__
